@@ -15,10 +15,10 @@ try:
 except ImportError:
     # Python < 2.6
     def isgeneratorfunction(obj):
-        return bool((inspect.isfunction(object) or inspect.ismethod(object)) and
-                    obj.func_code.co_flags & CO_GENERATOR)
+        return bool((inspect.isfunction(obj) or inspect.ismethod(obj)) and
+                    obj.func_code.co_flags & inspect.CO_GENERATOR)
 
-__version__ = '0.1.1'
+__version__ = '0.1.2'
 
 class CoroutineRunner(object):
     def __init__(self, generator, web_handler=None, io_loop=None):
@@ -32,7 +32,7 @@ class CoroutineRunner(object):
     def execute_work(self):
         return self.work(self.callback_proxy)
 
-    def callback_proxy(self, *args):
+    def callback_proxy(self, *args, **kwargs):
         try:
             if len(args) > 0:
                 if isinstance(args[-1], Exception):
@@ -64,6 +64,8 @@ class CoroutineRunner(object):
                         exc_info=True)
                 else:
                     self.web_handler._handle_request_exception(e)
+            else:
+                raise
 
 def make_asynchronous_decorator(io_loop):
     """
